CRDTRecord class

Constructors

CRDTRecord({required String id, required Map<String, dynamic> data, required VectorClock clock, bool tombstone = false})

Properties

clock VectorClock
getter/setter pair
data Map<String, dynamic>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tombstone bool
getter/setter pair

Methods

merge(CRDTRecord other) CRDTRecord
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited