CRDTSyncEngine class

Constructors

CRDTSyncEngine({required LocalStore store, required RemoteTransport transport, required String deviceId})

Properties

deviceId String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
store LocalStore
final
transport RemoteTransport
final

Methods

createOrUpdate(String recordId, Map<String, dynamic> data) Future<void>
delete(String recordId) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sync() Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited