LocalStore class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
applyOperation(
Operation operation) → Future< void> -
getRecord(
String id) → Future< CRDTRecord?> -
getUnsentOperations(
) → Future< List< Operation> > -
isApplied(
String opId) → Future< bool> -
markOperationSent(
String opId) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
saveOperation(
Operation operation) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited